@@ -1,3 +1,4 @@
+import mptt
 from django.db import models
 import uuid
 from django.utils import timezone
@@ -306,7 +307,7 @@ class HardwareStats(models.Model):
 
 
 
-class DataTransformer(MPTTModel):
+class DataTransformer(models.Model):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
     accessory = models.ForeignKey(
         Accessory,
@@ -314,7 +315,6 @@ class DataTransformer(MPTTModel):
         blank = False,
         null=False
     )
-    parent = TreeForeignKey('self', on_delete=models.CASCADE, null=True, blank=True, related_name='children')
     type = models.CharField(max_length=255,  blank=True, null=True, default=None)
     updated_at = models.DateTimeField(auto_now=True)
     created_at = models.DateTimeField(auto_now_add=True)
@@ -331,6 +331,8 @@ class DataTransformer(MPTTModel):
             models.Index(fields=['id','accessory']),
         ]
 
+TreeForeignKey(DataTransformer, on_delete=models.CASCADE, blank=True, null=True).contribute_to_class(DataTransformer, 'parent')
+mptt.register(DataTransformer)
 
 class DataTransformerConstants(models.Model):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
